==> texlive-lang_2017.20180305.orig.tar.xz: texlive-lang-2017.20180305/texmf-dist/fonts/cmap/uptex-fonts/cid_mapping.md <==
CID mapping memo
================

|                      |  | JIS X 0208   | JIS X 0213     | UCS    | H   | V     |
|----------------------|--|--------------|----------------|--------|:---:|:-----:|
|左シングル引用符      |‘| 01-38 0x2146 | 1-01-38 0x2146 | U+2018 | 670 | (670) |
|右シングル引用符      |’| 01-39 0x2147 | 1-01-39 0x2146 | U+2019 | 671 | (671) |
|左ダブル引用符        |“| 01-40 0x2148 | 1-01-40 0x2146 | U+201C | 672 | (672) |
|右ダブル引用符        |”| 01-41 0x2149 | 1-01-41 0x2146 | U+201D | 673 | (673) |
|始めダブルミニュート  |〝| ----- ------ | 1-13-64 0x2d60 | U+301D | --- | ---   |
|終わりダブルミニュート|〟| ----- ------ | 1-13-65 0x2d61 | U+301F | --- | ---   |
|コロン                |：| 01-07 0x2127 | 1-01-07 0x2127 | U+FF1A | 639 | (639) |
|セミコロン            |；| 01-08 0x2128 | 1-01-08 0x2128 | U+FF1B | 640 | (640) |

|                      |                                    |  | UCS    | UniJIS-UCS2-H | -V    |
|----------------------|------------------------------------|--|--------|:------:|:-------:|
|左シングル引用符      |LEFT SINGLE QUOTATION MARK          |‘| U+2018 |   670  |  8281   |
|右シングル引用符      |RIGHT SINGLE QUOTATION MARK         |’| U+2019 |   671  |  8282   |
|左ダブル引用符        |LEFT DOUBLE QUOTATION MARK          |“| U+201C |   672  |  8279   |
|右ダブル引用符        |RIGHT DOUBLE QUOTATION MARK         |”| U+201D |   673  |  8280   |
|始めダブルミニュート  |REVERSED DOUBLE PRIME QUOTATION MARK|〝| U+301D |  7608  |  7956   |
|終わりダブルミニュート|LOW DOUBLE PRIME QUOTATION MARK     |〟| U+301F |  7609  |  7957   |
|コロン                |FULLWIDTH COLON                     |：| U+FF1A |   639  |  (639)  |
|セミコロン            |FULLWIDTH SEMICOLON                 |；| U+FF1B |   640  |  (640)  |

|                      |                                    |  | UCS    | UniJIS-UTF16-H | -V   |
|----------------------|------------------------------------|--|--------|:------:|:-------:|
|左シングル引用符      |LEFT SINGLE QUOTATION MARK          |‘| U+2018 |    98  |   (98)  |
|右シングル引用符      |RIGHT SINGLE QUOTATION MARK         |’| U+2019 |    96  |   (96)  |
|左ダブル引用符        |LEFT DOUBLE QUOTATION MARK          |“| U+201C |   108  |  (108)  |
|右ダブル引用符        |RIGHT DOUBLE QUOTATION MARK         |”| U+201D |   122  |  (122)  |
|始めダブルミニュート  |REVERSED DOUBLE PRIME QUOTATION MARK|〝| U+301D |  7608  |  7956   |
|終わりダブルミニュート|LOW DOUBLE PRIME QUOTATION MARK     |〟| U+301F |  7609  |  7957   |
|コロン                |FULLWIDTH COLON                     |：| U+FF1A |   639  |  (639)  |
|セミコロン            |FULLWIDTH SEMICOLON                 |；| U+FF1B |   640  |  (640)  |

|                      |                                    |  | UCS    | UniJISup-UTF16-H | -V   |
|----------------------|------------------------------------|--|--------|:------:|:-------:|
|左シングル引用符      |LEFT SINGLE QUOTATION MARK          |‘| U+2018 |  [670] | [12173] |
|右シングル引用符      |RIGHT SINGLE QUOTATION MARK         |’| U+2019 |  [671] | [12174] |
|左ダブル引用符        |LEFT DOUBLE QUOTATION MARK          |“| U+201C |  [672] | [7956]  |
|右ダブル引用符        |RIGHT DOUBLE QUOTATION MARK         |”| U+201D |  [673] | [7957]  |
|始めダブルミニュート  |REVERSED DOUBLE PRIME QUOTATION MARK|〝| U+301D |  7608  |  7956   |
|終わりダブルミニュート|LOW DOUBLE PRIME QUOTATION MARK     |〟| U+301F |  7609  |  7957   |
|コロン                |FULLWIDTH COLON                     |：| U+FF1A |   639  | [12101] |
|セミコロン            |FULLWIDTH SEMICOLON                 |；| U+FF1B |   640  | (640)   |


|                      |  | UCS    | UniJIS-UTF16-H | -V   |
|----------------------|--|--------|:------:|:-------:|
|BLACK RIGHTWARDS ARROW|➡| U+27A1 |  8206  |  8209   |
|LEFTWARDS BLACK ARROW |⬅| U+2B05 |  8207  | (8207)  |
|UPWARDS BLACK ARROW   |⬆| U+2B06 |  8208  | (8208)  |
|DOWNWARDS BLACK ARROW |⬇| U+2B07 |  8209  | (8209)  |
|RIGHTWARDS BLACK ARROW|⮕| U+2B95 |  8206  | (8206)  |

|                      |  | UCS    | UniJISup-UTF16-H | -V   |
|----------------------|--|--------|:------:|:-------:|
|BLACK RIGHTWARDS ARROW|➡| U+27A1 |  8206  |  8209   |
|LEFTWARDS BLACK ARROW |⬅| U+2B05 |  8207  | [8208]  |
|UPWARDS BLACK ARROW   |⬆| U+2B06 |  8208  | [8206]  |
|DOWNWARDS BLACK ARROW |⬇| U+2B07 |  8209  | [8207]  |
|RIGHTWARDS BLACK ARROW|⮕| U+2B95 |  8206  | [8209]  |

[]が UniJISup-UTF16-{H,V} で追加したCID指定。

UniJISup-UTF16-V では、上記の表以外に UniJISPro-UCS2-V に倣って
U+337B..U+337E の縦組み字形 12044..12041 を追加。

UniJISup-* で追加したCIDは全てAdobe-Japan1-4の範囲("Pro", CID15443まで)に収まっているが、
一部はAdobe-Japan1-3の範囲("Std", CID9353まで)を超えている。

==> texlive-lang_2019.20200218.orig.tar.xz: texlive-lang-2019.20200218/texmf-dist/fonts/cmap/uptex-fonts/cid_mapping.md <==
CID mapping memo
================

|                      |  | JIS X 0208   | JIS X 0213     | UCS    | H   | V     |
|----------------------|--|--------------|----------------|--------|:---:|:-----:|
|左シングル引用符      |‘| 01-38 0x2146 | 1-01-38 0x2146 | U+2018 | 670 | (670) |
|右シングル引用符      |’| 01-39 0x2147 | 1-01-39 0x2146 | U+2019 | 671 | (671) |
|左ダブル引用符        |“| 01-40 0x2148 | 1-01-40 0x2146 | U+201C | 672 | (672) |
|右ダブル引用符        |”| 01-41 0x2149 | 1-01-41 0x2146 | U+201D | 673 | (673) |
|始めダブルミニュート  |〝| ----- ------ | 1-13-64 0x2d60 | U+301D | --- | ---   |
|                      |〞| ----- ------ | ------- ------ | U+301E | --- | ---   |
|終わりダブルミニュート|〟| ----- ------ | 1-13-65 0x2d61 | U+301F | --- | ---   |
|コロン                |：| 01-07 0x2127 | 1-01-07 0x2127 | U+FF1A | 639 | (639) |
|セミコロン            |；| 01-08 0x2128 | 1-01-08 0x2128 | U+FF1B | 640 | (640) |

|                      |                                    |  | UCS    | UniJIS-UCS2-H | -V    |
|----------------------|------------------------------------|--|--------|:------:|:-------:|
|左シングル引用符      |LEFT SINGLE QUOTATION MARK          |‘| U+2018 |   670  |  8281   |
|右シングル引用符      |RIGHT SINGLE QUOTATION MARK         |’| U+2019 |   671  |  8282   |
|左ダブル引用符        |LEFT DOUBLE QUOTATION MARK          |“| U+201C |   672  |  8279   |
|右ダブル引用符        |RIGHT DOUBLE QUOTATION MARK         |”| U+201D |   673  |  8280   |
|始めダブルミニュート  |REVERSED DOUBLE PRIME QUOTATION MARK|〝| U+301D |  7608  |  7956   |
|                      |DOUBLE PRIME QUOTATION MARK         |〞| U+301E |  ---   |  ---    |
|終わりダブルミニュート|LOW DOUBLE PRIME QUOTATION MARK     |〟| U+301F |  7609  |  7957   |
|コロン                |FULLWIDTH COLON                     |：| U+FF1A |   639  |  (639)  |
|セミコロン            |FULLWIDTH SEMICOLON                 |；| U+FF1B |   640  |  (640)  |

|                      |                                    |  | UCS    | UniJIS-UTF16-H | -V   |
|----------------------|------------------------------------|--|--------|:------:|:-------:|
|左シングル引用符      |LEFT SINGLE QUOTATION MARK          |‘| U+2018 |    98  |   (98)  |
|右シングル引用符      |RIGHT SINGLE QUOTATION MARK         |’| U+2019 |    96  |   (96)  |
|左ダブル引用符        |LEFT DOUBLE QUOTATION MARK          |“| U+201C |   108  |  (108)  |
|右ダブル引用符        |RIGHT DOUBLE QUOTATION MARK         |”| U+201D |   122  |  (122)  |
|始めダブルミニュート  |REVERSED DOUBLE PRIME QUOTATION MARK|〝| U+301D |  7608  |  7956   |
|                      |DOUBLE PRIME QUOTATION MARK         |〞| U+301E | 12170  | (12170) |
|終わりダブルミニュート|LOW DOUBLE PRIME QUOTATION MARK     |〟| U+301F |  7609  |  7957   |
|コロン                |FULLWIDTH COLON                     |：| U+FF1A |   639  | 12101 |
|セミコロン            |FULLWIDTH SEMICOLON                 |；| U+FF1B |   640  |  (640)  |

|                      |                                    |  | UCS    | UniJISup-UTF16-H | -V   |
|----------------------|------------------------------------|--|--------|:------:|:-------:|
|左シングル引用符      |LEFT SINGLE QUOTATION MARK          |‘| U+2018 |  [670] | [12173] |
|右シングル引用符      |RIGHT SINGLE QUOTATION MARK         |’| U+2019 |  [671] | [12174] |
|左ダブル引用符        |LEFT DOUBLE QUOTATION MARK          |“| U+201C |  [672] | [7956]  |
|右ダブル引用符        |RIGHT DOUBLE QUOTATION MARK         |”| U+201D |  [673] | [7957]  |
|始めダブルミニュート  |REVERSED DOUBLE PRIME QUOTATION MARK|〝| U+301D |  7608  |  7956   |
|                      |DOUBLE PRIME QUOTATION MARK         |〞| U+301E | 12170  | [7957]  |
|終わりダブルミニュート|LOW DOUBLE PRIME QUOTATION MARK     |〟| U+301F |  7609  |  7957   |
|コロン                |FULLWIDTH COLON                     |：| U+FF1A |   639  | 12101 |
|セミコロン            |FULLWIDTH SEMICOLON                 |；| U+FF1B |   640  | (640)   |


|                      |  | UCS    | UniJIS-UTF16-H | -V   |
|----------------------|--|--------|:------:|:-------:|
|BLACK RIGHTWARDS ARROW|➡| U+27A1 |  8206  |  8209   |
|LEFTWARDS BLACK ARROW |⬅| U+2B05 |  8207  | (8207)  |
|UPWARDS BLACK ARROW   |⬆| U+2B06 |  8208  | (8208)  |
|DOWNWARDS BLACK ARROW |⬇| U+2B07 |  8209  | (8209)  |
|RIGHTWARDS BLACK ARROW|⮕| U+2B95 |  8206  | (8206)  |

|                      |  | UCS    | UniJISup-UTF16-H | -V   |
|----------------------|--|--------|:------:|:-------:|
|BLACK RIGHTWARDS ARROW|➡| U+27A1 |  8206  |  8209   |
|LEFTWARDS BLACK ARROW |⬅| U+2B05 |  8207  | [8208]  |
|UPWARDS BLACK ARROW   |⬆| U+2B06 |  8208  | [8206]  |
|DOWNWARDS BLACK ARROW |⬇| U+2B07 |  8209  | [8207]  |
|RIGHTWARDS BLACK ARROW|⮕| U+2B95 |  8206  | [8209]  |

[]が UniJISup-UTF16-{H,V} で追加したCID指定。

オリジナルの UniJIS-UTF16-{H,V} (Version 07/30/2018)に
U+32FF (新元号の組文字, CID:23058..23059) が追加された。
また、UniJIS-UTF16-V (Version 07/30/2018)に
U+337B..337E(元号の組文字), U+FF1A(FULLWIDTH COLON) の縦組み字形が追加された。
UniJISup-UTF16-{H,V} はこれらを踏襲した。

UniJISup-UTF16-V では、上記の表以外に UniJISPro-UCS2-V, UniJIS-UTF16-V(07/30/2018以降) に倣って
U+337B..337E(元号の組文字) の縦組み字形 12044..12041 を追加。

UniJISup-* で追加したCIDは全てAdobe-Japan1-4の範囲("Pro", CID15443まで)に収まっているが、
一部はAdobe-Japan1-3の範囲("Std", CID9353まで)を超えている。
